@@ -28,22 +28,19 @@ fn bench_pdf(c: &mut Criterion) {
 
     {
         let mvn = mvn.clone();
-        let xs = OMatrix::<f64, nalgebra::Dynamic, U2>::from_fn(
-            100000,
-            |row, col| {
-                if col == 0 {
-                    row as f64
-                } else {
-                    1.0
-                }
-            },
-        );
+        let xs = OMatrix::<f64, nalgebra::Dynamic, U2>::from_fn(100000, |row, col| {
+            if col == 0 {
+                row as f64
+            } else {
+                1.0
+            }
+        });
 
         c.bench_function("pdf_big", move |b| b.iter(|| mvn.pdf(&xs)));
     }
 
     {
-        let mvn = mvn.clone();
+        let mvn = mvn;
         // input samples are row vectors vertically stacked
         let xs = OMatrix::<_, U3, U2>::new(8.9, 1.0, 9.0, 1.0, 9.1, 1.0);
 
